==> xmule_1.8.2b.orig.tar.gz: xmule-1.8.2b/src/PPgDirectories.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGDIR_H
#define PPGDIR_H

#include "DirectoryTreeCtrl.h"
#include "Preferences.h"
#include "resource.h"

#include <wx/panel.h>

// CPPgDirectories dialog

class CPPgDirectories : public wxPanel //CPropertyPage
{
  //DECLARE_DYNAMIC(CPPgDirectories)
  DECLARE_DYNAMIC_CLASS(CPPgDirectories)
    CPPgDirectories() {};

public:
	CPPgDirectories(wxWindow* parent);									// standard constructor
	virtual ~CPPgDirectories();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum { IDD = IDD_PPG_DIRECTORIES };

protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//DECLARE_MESSAGE_MAP()
	DECLARE_EVENT_TABLE()

public:
	//virtual BOOL OnInitDialog();
public:
	CDirectoryTreeCtrl* m_ShareSelector;
	CPreferences* app_prefs;
private:
	bool SelectDir(char* outdir, char* titletext);
public:
	void OnBnClickedSelincdir(wxEvent& e);
	void OnBnClickedSeltempdir(wxEvent& e);
	void BrowseVideoplayer(wxEvent& e);

	virtual BOOL OnApply();
#if 0

	afx_msg void OnBnClickedSelincdir();
	afx_msg void OnBnClickedSeltempdir();
	
	afx_msg void OnEnChangeIncfiles()	{ SetModified(); }
	afx_msg void OnEnChangeTempfiles()	{ SetModified(); }
	afx_msg void OnBnClickedCheck1()	{ SetModified(); }
protected:
	virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
#endif
public:
	void Localize(void);
	void LoadSettings(void);
};

#endif

==> xmule_1.10.0b.orig.tar.gz: xmule-1.10.0b.orig/src/PPgDirectories.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGDIR_H
#define PPGDIR_H

#include "resource.h"

#include <wx/panel.h>

class CPreferences;

class CDirectoryTreeCtrl: public wxWindow
{
};

class CPPgDirectories : public wxPanel //CPropertyPage
{
  //DECLARE_DYNAMIC(CPPgDirectories)
  DECLARE_DYNAMIC_CLASS(CPPgDirectories)
    CPPgDirectories() {};

public:
	CPPgDirectories(wxWindow* parent) { }
	virtual ~CPPgDirectories() { }

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum { IDD = IDD_PPG_DIRECTORIES };

protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//DECLARE_MESSAGE_MAP()
	DECLARE_EVENT_TABLE()

public:
	//virtual bool OnInitDialog();
public:
	CDirectoryTreeCtrl* m_ShareSelector;
	CPreferences* app_prefs;
private:
	bool SelectDir(char* outdir, char* titletext);
public:
	void OnBnClickedSelincdir(wxCommandEvent& e);
	void OnBnClickedSeltempdir(wxCommandEvent& e);
	void BrowseVideoplayer(wxCommandEvent& e);

	virtual bool OnApply();
#if 0

	afx_msg void OnBnClickedSelincdir();
	afx_msg void OnBnClickedSeltempdir();
	
	afx_msg void OnEnChangeIncfiles()	{ SetModified(); }
	afx_msg void OnEnChangeTempfiles()	{ SetModified(); }
	afx_msg void OnBnClickedCheck1()	{ SetModified(); }
protected:
	virtual bool OnCommand(WPARAM wParam, LPARAM lParam);
#endif
public:
	void Localize(void);
	void LoadSettings(void);
};

#endif
